@@ -4,8 +4,9 @@ import datetime
 import json
 
 from moto.compat import OrderedDict
-from moto.core import BaseBackend, BaseModel
+from moto.core import BaseBackend, BaseModel, CloudFormationModel
 from moto.core.utils import unix_time
+from moto.core import ACCOUNT_ID
 from .comparisons import get_comparison_func
 
 
@@ -81,7 +82,7 @@ class Item(BaseModel):
         return {"Item": included}
 
 
-class Table(BaseModel):
+class Table(CloudFormationModel):
     def __init__(
         self,
         name,
@@ -134,6 +135,15 @@ class Table(BaseModel):
             }
         return results
 
+    @staticmethod
+    def cloudformation_name_type():
+        return "TableName"
+
+    @staticmethod
+    def cloudformation_type():
+        # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dynamodb-table.html
+        return "AWS::DynamoDB::Table"
+
     @classmethod
     def create_from_cloudformation_json(
         cls, resource_name, cloudformation_json, region_name
@@ -277,8 +287,8 @@ class Table(BaseModel):
         if attribute_name == "StreamArn":
             region = "us-east-1"
             time = "2000-01-01T00:00:00.000"
-            return "arn:aws:dynamodb:{0}:123456789012:table/{1}/stream/{2}".format(
-                region, self.name, time
+            return "arn:aws:dynamodb:{0}:{1}:table/{2}/stream/{3}".format(
+                region, ACCOUNT_ID, self.name, time
             )
         raise UnformattedGetAttTemplateException()
 
