@@ -179,15 +179,27 @@ class EmailResponse(BaseResponse):
     def create_template(self):
         template_data = self._get_dict_param("Template")
         template_info = {}
-        template_info["text_part"] = template_data["._text_part"]
-        template_info["html_part"] = template_data["._html_part"]
-        template_info["template_name"] = template_data["._name"]
-        template_info["subject_part"] = template_data["._subject_part"]
+        template_info["text_part"] = template_data.get("._text_part", "")
+        template_info["html_part"] = template_data.get("._html_part", "")
+        template_info["template_name"] = template_data.get("._name", "")
+        template_info["subject_part"] = template_data.get("._subject_part", "")
         template_info["Timestamp"] = datetime.utcnow()
         ses_backend.add_template(template_info=template_info)
         template = self.response_template(CREATE_TEMPLATE)
         return template.render()
 
+    def update_template(self):
+        template_data = self._get_dict_param("Template")
+        template_info = {}
+        template_info["text_part"] = template_data.get("._text_part", "")
+        template_info["html_part"] = template_data.get("._html_part", "")
+        template_info["template_name"] = template_data.get("._name", "")
+        template_info["subject_part"] = template_data.get("._subject_part", "")
+        template_info["Timestamp"] = datetime.utcnow()
+        ses_backend.update_template(template_info=template_info)
+        template = self.response_template(UPDATE_TEMPLATE)
+        return template.render()
+
     def get_template(self):
         template_name = self._get_param("TemplateName")
         template_data = ses_backend.get_template(template_name)
@@ -199,6 +211,12 @@ class EmailResponse(BaseResponse):
         template = self.response_template(LIST_TEMPLATES)
         return template.render(templates=email_templates)
 
+    def test_render_template(self):
+        render_info = self._get_dict_param("Template")
+        rendered_template = ses_backend.render_template(render_info)
+        template = self.response_template(RENDER_TEMPLATE)
+        return template.render(template=rendered_template)
+
     def create_receipt_rule_set(self):
         rule_set_name = self._get_param("RuleSetName")
         ses_backend.create_receipt_rule_set(rule_set_name)
@@ -341,10 +359,10 @@ GET_SEND_STATISTICS = """<GetSendStatisticsResponse xmlns="http://ses.amazonaws.
             </item>
         {% endfor %}
       </SendDataPoints>
-      <ResponseMetadata>
-        <RequestId>e0abcdfa-c866-11e0-b6d0-273d09173z49</RequestId>
-      </ResponseMetadata>
   </GetSendStatisticsResult>
+  <ResponseMetadata>
+    <RequestId>e0abcdfa-c866-11e0-b6d0-273d09173z49</RequestId>
+  </ResponseMetadata>
 </GetSendStatisticsResponse>"""
 
 CREATE_CONFIGURATION_SET = """<CreateConfigurationSetResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
@@ -369,12 +387,19 @@ CREATE_TEMPLATE = """<CreateTemplateResponse xmlns="http://ses.amazonaws.com/doc
   </ResponseMetadata>
 </CreateTemplateResponse>"""
 
+UPDATE_TEMPLATE = """<UpdateTemplateResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
+  <UpdateTemplateResult/>
+  <ResponseMetadata>
+    <RequestId>47e0ef1a-9bf2-11e1-9279-0100e8cf12ba</RequestId>
+  </ResponseMetadata>
+</UpdateTemplateResponse>"""
+
 GET_TEMPLATE = """<GetTemplateResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
     <GetTemplateResult>
         <Template>
             <TemplateName>{{ template_data["template_name"] }}</TemplateName>
             <SubjectPart>{{ template_data["subject_part"] }}</SubjectPart>
-            <HtmlPart>{{ template_data["html_part"] }}</HtmlPart>
+            <HtmlPart><![CDATA[{{ template_data["html_part"] }}]]></HtmlPart>
             <TextPart>{{ template_data["text_part"] }}</TextPart>
         </Template>
     </GetTemplateResult>
@@ -383,6 +408,7 @@ GET_TEMPLATE = """<GetTemplateResponse xmlns="http://ses.amazonaws.com/doc/2010-
     </ResponseMetadata>
 </GetTemplateResponse>"""
 
+
 LIST_TEMPLATES = """<ListTemplatesResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
     <ListTemplatesResult>
         <TemplatesMetadata>
@@ -399,6 +425,19 @@ LIST_TEMPLATES = """<ListTemplatesResponse xmlns="http://ses.amazonaws.com/doc/2
     </ResponseMetadata>
 </ListTemplatesResponse>"""
 
+RENDER_TEMPLATE = """
+<TestRenderTemplateResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
+    <TestRenderTemplateResult>
+      <RenderedTemplate>
+      {{template | e}}
+      </RenderedTemplate>
+    </TestRenderTemplateResult>
+    <ResponseMetadata>
+        <RequestId>47e0ef1a-9bf2-11e1-9279-0100e8cf12ba</RequestId>
+    </ResponseMetadata>
+</TestRenderTemplateResponse>
+"""
+
 CREATE_RECEIPT_RULE_SET = """<CreateReceiptRuleSetResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
   <CreateReceiptRuleSetResult/>
   <ResponseMetadata>
